@@ -1,4 +1,10 @@
 from .application_middleware import ApplicationMiddleware
-from .middleware import Middleware, MiddlewareCursor, MiddlewareFunction, MiddlewareHandler, MiddlewarePipeline
+from .middleware import (
+    Middleware,
+    MiddlewareCursor,
+    MiddlewareFunction,
+    MiddlewareHandler,
+    MiddlewarePipeline,
+)
 from .open_api_middleware import OpenApiMiddleware
 from .parsed_body_middleware import ParsedBodyMiddleware
